Skip to contents

This is the general holding class for STS2 map points.

Value

A new STS2Map object.

Public fields

run

The run

floors

The floors in the map. A list of STS2Floor objects.

Methods


Method new()

Create a new map object from map data.

Usage

STS2Map$new(mapdata, run = NULL)

Arguments

mapdata

The subset of the list output from jsonlite, usually passed in via STS2Player.

run

The STS2Run object this map belongs to.


Method clone()

The objects of this class are cloneable with this method.

Usage

STS2Map$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.