Calculate (and potentially plot) winrates by character.
Source:R/winrate_character.R
winrate_character.RdCalculate (and potentially plot) winrates by character.
Usage
winrate_character(
runhistory,
plotit = TRUE,
relative = FALSE,
expected = NULL,
ignoreabandoned = FALSE,
ci = TRUE,
samples = 200,
lower_quant = 0.025,
upper_quant = 0.975
)Arguments
- runhistory
An STS2RunHistory object, filtered if necessary.
- plotit
Whether to plot the data or just return a summary
data.frame- relative
Whether to calculate the character-based winrate relative to the total winrate.
- expected
If set, the expected winrate to scale values relative to (automatically turns on
relativewhen set).- ignoreabandoned
Remove abandoned runs from data prior to analysis (otherwise abandoned runs count as losses).
- ci
Whether to calculate and plot 95% confidence intervals
- samples
The number of iterations to use when generating CIs.
- lower_quant
The lower quantile of the CIs.
- upper_quant
The upper quantile of the CIs.
Examples
if (FALSE) { # interactive()
myruns <- load_sts_history()
winrate_character(myruns)
}