This is the general holding class for a set of sts2 Cards. It stores the main card data for the player.
Public fields
playerThe STS2Player object this deck belongs to.
cardsA list of cards.
floorfoundThe floors upon which the cards were found.
upgradelevelThe upgrade level of each card.
enchantmentsThe enchantments assigned to each card
enchantamtThe amount of an enchantment assigned to each card
Methods
Method new()
Create a new deck object from player data.
Usage
STS2Deck$new(carddata, player = NULL)Arguments
carddataThe subset of the list output from jsonlite, usually passed in via STS2Player.
playerThe STS2Player object this deck belongs to.
Method print()
Print an STS2Deck object.