This is the general holding class for an sts2 player. It stores the main player data for the run.
Public fields
runThe STS2Run object that this player object originates from.
playercharacterThe character that the player was playing
deckThe deck of the player at the end of the run. An STS2Deck object.
idThe steam player id or 1 if single player.
max_potion_slot_countThe maximum number of potions a player could hold.
potionsThe potions held by the player at the end of the run.
relicsThe relics held by the player at the end of the run. An STS2Relics object
Methods
Method new()
Create a new run object from player data.
Usage
STS2Player$new(playerdata, run = NULL, idx = 1)Arguments
playerdataThe subset of the list output from jsonlite, usually passed in via STS2Run.
runThe STS2Run object that this player object originates from.
idxThe index within the player list from which this player originates.
Method print()
Print an STS2Player object.
Arguments
...Arguments to pass to
print().fullWhether to show the full deck and relics of the player.
floorWhether to show the floor on which a card/relic was obtained when
full = TRUE.