This is the general holding class for a set of sts2 relics. It stores the main relic data for the player.
Public fields
playerThe STS2Player object these relics belong to.
relicnamesA list of relics.
floorfoundThe floors upon which the relics were found.
extra_dataThe extra_data associated with the relics (unparsed)
Methods
Method new()
Create a new relics object from player data.
Usage
STS2Relics$new(relicdata, player = NULL)Arguments
relicdataThe subset of the list output from jsonlite, usually passed in via STS2Player.
playerThe STS2Player object these relics belong to.
Method print()
Print an STS2Relics object.