This is the general holding class for an sts2 run. It stores the main metadata and lists containing more in-depth run data.
Public fields
actsA vector of the acts that the player encountered.
ascensionThe ascension level of the run.
build_idThe build of the game that this run was generated from.
game_modeThe game mode that the player was playing.
killed_by_encounterThe encounter that killed the player.
killed_by_eventThe event that killed the player.
mapA list storing the play-by-play of the run. An STS2Map object.
modifiersAny modifiers that the player had turned on.
platform_typeThe platform of the game (e.g. steam).
playersA list of player information. A list of STS2Player objects.
run_timeThe run duration (in seconds).
schema_versionThe run schema version.
seedThe seed of the run.
start_timeThe start time (in seconds from unix epoch, UTC).
was_abandonedWhether the player abandoned the run.
winWhether the player won the run.
owneridThe steam ID of the run owner.
Active bindings
outcomeThe outcome of the run.
numplayersThe number of players in the run.
numfloorsThe number of floors in the run.
Methods
Method new()
Create a new run object from data parsed with jsonlite.
Usage
STS2Run$new(rundata, steamid = NULL)Method print()
Print an STS2Run object.